"""
Auto-generated observer constants from LVGL headers.

Do not edit manually. Regenerate from the GDB script root with:
    python3 scripts/generate_all.py
"""

SUBJECT_TYPE_NAMES = {
    0: "INVALID",
    1: "NONE",
    2: "INT",
    3: "FLOAT",
    4: "POINTER",
    5: "COLOR",
    6: "GROUP",
    7: "STRING",
}
