"""
Auto-generated event constants from LVGL headers.

Do not edit manually. Regenerate from the GDB script root with:
    python3 scripts/generate_all.py
"""

EVENT_CODE_NAMES = {
    0: "ALL",
    1: "PRESSED",
    2: "PRESSING",
    3: "PRESS_LOST",
    4: "SHORT_CLICKED",
    5: "SINGLE_CLICKED",
    6: "DOUBLE_CLICKED",
    7: "TRIPLE_CLICKED",
    8: "LONG_PRESSED",
    9: "LONG_PRESSED_REPEAT",
    10: "CLICKED",
    11: "RELEASED",
    12: "SCROLL_BEGIN",
    13: "SCROLL_THROW_BEGIN",
    14: "SCROLL_END",
    15: "SCROLL",
    16: "GESTURE",
    17: "KEY",
    18: "ROTARY",
    19: "FOCUSED",
    20: "DEFOCUSED",
    21: "LEAVE",
    22: "HIT_TEST",
    23: "INDEV_RESET",
    24: "HOVER_OVER",
    25: "HOVER_LEAVE",
    26: "COVER_CHECK",
    27: "REFR_EXT_DRAW_SIZE",
    28: "DRAW_MAIN_BEGIN",
    29: "DRAW_MAIN",
    30: "DRAW_MAIN_END",
    31: "DRAW_POST_BEGIN",
    32: "DRAW_POST",
    33: "DRAW_POST_END",
    34: "DRAW_TASK_ADDED",
    35: "VALUE_CHANGED",
    36: "INSERT",
    37: "REFRESH",
    38: "READY",
    39: "CANCEL",
    40: "STATE_CHANGED",
    41: "CREATE",
    42: "DELETE",
    43: "CHILD_CHANGED",
    44: "CHILD_CREATED",
    45: "CHILD_DELETED",
    46: "SCREEN_UNLOAD_START",
    47: "SCREEN_LOAD_START",
    48: "SCREEN_LOADED",
    49: "SCREEN_UNLOADED",
    50: "SIZE_CHANGED",
    51: "STYLE_CHANGED",
    52: "LAYOUT_CHANGED",
    53: "GET_SELF_SIZE",
    54: "INVALIDATE_AREA",
    55: "RESOLUTION_CHANGED",
    56: "COLOR_FORMAT_CHANGED",
    57: "REFR_REQUEST",
    58: "REFR_START",
    59: "REFR_READY",
    60: "RENDER_START",
    61: "RENDER_READY",
    62: "FLUSH_START",
    63: "FLUSH_FINISH",
    64: "FLUSH_WAIT_START",
    65: "FLUSH_WAIT_FINISH",
    66: "SYNC_START",
    67: "SYNC_FINISH",
    68: "SYNC_WAIT_START",
    69: "SYNC_WAIT_FINISH",
    70: "UPDATE_LAYOUT_COMPLETED",
    71: "VSYNC",
    72: "VSYNC_REQUEST",
    73: "TRANSLATION_LANGUAGE_CHANGED",
}
