"""
Auto-generated indev constants from LVGL headers.

Do not edit manually. Regenerate from the GDB script root with:
    python3 scripts/generate_all.py
"""

INDEV_TYPE_NAMES = {
    0: "NONE",
    1: "POINTER",
    2: "KEYPAD",
    3: "BUTTON",
    4: "ENCODER",
}
